Learn R Programming

allometric (version 2.1.0)

check_country_in_iso: Checks if a country code is defined in ISO_3166_1$Alpha_2

Description

Checks if a country code is defined in ISO_3166_1$Alpha_2

Usage

check_country_in_iso(country_codes)

Arguments