Learn R Programming

allometric (version 2.1.0)

check_region_in_iso: Checks if a region code is defined in the ISO_3166_2 table

Description

Checks if a region code is defined in the ISO_3166_2 table

Usage

check_region_in_iso(region_codes)

Arguments