Learn R Programming

allometric (version 2.1.0)

get_pub_file_specs: Retrieve all publication file names in the publication subdirectories

Description

The publication subdirectories divide the publications into groups sorted by last name. This function returns a list containing the publication paths and the publication names.

Usage

get_pub_file_specs(pub_path)

Arguments