Learn R Programming

allometric (version 2.1.0)

unnest_models.model_tbl: Unnest the columns of model_tbl

Description

A model_tbl often contains nested information within the cells of the table. This function allows a user to unnest the columns of interest.

Usage

# S3 method for model_tbl
unnest_models(data, cols)

Value

The unnested model_tbl

Arguments

data

A model_tbl

cols

A character vector of columns to unnest