Learn R Programming

allometric (version 2.1.0)

unnest_taxa: Unnest the taxa column of a model_tbl

Description

In some cases it is convenient to expand the taxonomic specifications for each model contained in the taxa column. This function achieves this, and adds family, genus, and species character columns. Models with more than one taxon are replicated as new rows.

Usage

unnest_taxa(data)

Value

A model_tbl with family, genus and species columns attached

Arguments

data

A model_tbl